@@ -14,9 +14,15 @@
 from __future__ import absolute_import, division, print_function
 from __future__ import unicode_literals
 
+import sys
 import os.path
 import textwrap
 
+try:
+    import builtins
+except ImportError:
+    import __builtin__ as builtins
+
 import pytest
 
 from twine import utils
@@ -115,6 +121,8 @@ def test_get_repository_config_missing(tmpdir):
     }
     assert (utils.get_repository_from_config(pypirc, 'foo', repository_url) ==
             exp)
+    assert (utils.get_repository_from_config(pypirc, 'pypi', repository_url) ==
+            exp)
     exp = {
             "repository": utils.DEFAULT_REPOSITORY,
             "username": None,
@@ -172,3 +180,75 @@ def test_default_to_environment_action(env_name, default, environ, expected):
         )
     assert action.env == env_name
     assert action.default == expected
+
+
+def test_get_password_keyring_overrides_prompt(monkeypatch):
+    class MockKeyring:
+        @staticmethod
+        def get_password(system, user):
+            return '{user}@{system} sekure pa55word'.format(**locals())
+
+    monkeypatch.setitem(sys.modules, 'keyring', MockKeyring)
+
+    pw = utils.get_password('system', 'user', None, {})
+    assert pw == 'user@system sekure pa55word'
+
+
+def test_get_password_keyring_defers_to_prompt(monkeypatch):
+    monkeypatch.setattr(utils, 'password_prompt', lambda prompt: 'entered pw')
+
+    class MockKeyring:
+        @staticmethod
+        def get_password(system, user):
+            return
+
+    monkeypatch.setitem(sys.modules, 'keyring', MockKeyring)
+
+    pw = utils.get_password('system', 'user', None, {})
+    assert pw == 'entered pw'
+
+
+@pytest.fixture
+def keyring_missing(monkeypatch):
+    """
+    Simulate that 'import keyring' raises an ImportError
+    """
+    real_import = builtins.__import__
+
+    def my_import(name, *args, **kwargs):
+        if name == 'keyring':
+            raise ImportError
+        return real_import(name, *args, **kwargs)
+    monkeypatch.setattr(builtins, '__import__', my_import)
+
+
+@pytest.fixture
+def entered_password(monkeypatch):
+    monkeypatch.setattr(utils, 'password_prompt', lambda prompt: 'entered pw')
+
+
+def test_get_password_keyring_missing_prompts(
+        entered_password, keyring_missing):
+    assert utils.get_password('system', 'user', None, {}) == 'entered pw'
+
+
+@pytest.fixture
+def keyring_no_backends(monkeypatch):
+    """
+    Simulate that keyring has no available backends. When keyring
+    has no backends for the system, the backend will be a
+    fail.Keyring, which raises RuntimeError on get_password.
+    """
+    class FailKeyring(object):
+        @staticmethod
+        def get_password(system, username):
+            raise RuntimeError("fail!")
+    monkeypatch.setitem(sys.modules, 'keyring', FailKeyring())
+
+
+def test_get_password_runtime_error_suppressed(
+        entered_password, keyring_no_backends, recwarn):
+    assert utils.get_password('system', 'user', None, {}) == 'entered pw'
+    assert len(recwarn) == 1
+    warning = recwarn.pop(UserWarning)
+    assert 'fail!' in str(warning)
