@@ -1,4 +1,4 @@
-# Copyright 2013 Donald Stufft
+# Copyright 2018 Donald Stufft and individual contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,21 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from __future__ import absolute_import, division, print_function
-from __future__ import unicode_literals
 
-__all__ = [
+__all__ = (
     "__title__", "__summary__", "__uri__", "__version__", "__author__",
     "__email__", "__license__", "__copyright__",
-]
+)
 
 __title__ = "twine"
-__summary__ = "Collection of utilities for interacting with PyPI"
-__uri__ = "https://github.com/dstufft/twine"
+__summary__ = "Collection of utilities for publishing packages on PyPI"
+__uri__ = "http://twine.readthedocs.io/"
 
-__version__ = "1.3.1"
+__version__ = "1.10.0"
 
 __author__ = "Donald Stufft and individual contributors"
 __email__ = "donald@stufft.io"
 
 __license__ = "Apache License, Version 2.0"
-__copyright__ = "Copyright 2013 Donald Stufft"
+__copyright__ = "Copyright 2018 Donald Stufft and individual contributors"
